==> zio-aws-groundstation_2.12-5.17.103.1-sources.jar: zio/aws/groundstation/model/CancelContactRequest.scala <==
package zio.aws.groundstation.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class CancelContactRequest(contactId: String) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.CancelContactRequest = {
    import CancelContactRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.CancelContactRequest
      .builder()
      .contactId(contactId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.groundstation.model.CancelContactRequest.ReadOnly =
    zio.aws.groundstation.model.CancelContactRequest.wrap(buildAwsValue())
}
object CancelContactRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.CancelContactRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.CancelContactRequest =
      zio.aws.groundstation.model.CancelContactRequest(contactId)
    def contactId: String
    def getContactId: ZIO[Any, Nothing, String] = ZIO.succeed(contactId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.CancelContactRequest
  ) extends zio.aws.groundstation.model.CancelContactRequest.ReadOnly {
    override val contactId: String = impl.contactId(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.CancelContactRequest
  ): zio.aws.groundstation.model.CancelContactRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-groundstation_2.12-5.20.37.1-sources.jar: zio/aws/groundstation/model/CancelContactRequest.scala <==
package zio.aws.groundstation.model
import zio.aws.groundstation.model.primitives.Uuid
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class CancelContactRequest(contactId: Uuid) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.CancelContactRequest = {
    import CancelContactRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.CancelContactRequest
      .builder()
      .contactId(Uuid.unwrap(contactId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.groundstation.model.CancelContactRequest.ReadOnly =
    zio.aws.groundstation.model.CancelContactRequest.wrap(buildAwsValue())
}
object CancelContactRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.CancelContactRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.CancelContactRequest =
      zio.aws.groundstation.model.CancelContactRequest(contactId)
    def contactId: Uuid
    def getContactId: ZIO[Any, Nothing, Uuid] = ZIO.succeed(contactId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.CancelContactRequest
  ) extends zio.aws.groundstation.model.CancelContactRequest.ReadOnly {
    override val contactId: Uuid =
      zio.aws.groundstation.model.primitives.Uuid(impl.contactId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.CancelContactRequest
  ): zio.aws.groundstation.model.CancelContactRequest.ReadOnly = new Wrapper(
    impl
  )
}
